@@ -1,6 +1,7 @@
 # -*- coding:utf-8 -*-
 from __future__ import absolute_import
 from __future__ import unicode_literals
+from __future__ import print_function
 import datetime
 
 
@@ -9,19 +10,20 @@ class Converter(object):
     変換
     """
 
-    def __init__(self, config, quiet=False):
+    def __init__(self, config, quiet=False, indent=1):
         """
         :param quiet: 処理状況を出力しない
         :type quiet: bool
         """
         self.config = config
         self.quiet = quiet
+        self.indent = indent
 
     def echo(self, message, start_at=None):
         if self.quiet:
             return
 
-        text = '--{} {}'.format(self.config.name, message)
+        text = '{}{} {}'.format('--' * self.indent, self.config.name, message)
         if start_at:
             delta = datetime.datetime.now() - start_at
             text += ' ({}.{}s)'.format(delta.seconds, delta.microseconds)
@@ -31,15 +33,14 @@ class Converter(object):
     def run(self):
         self.save(self.convert())
 
-    def convert(self, target_fields=None):
+    def convert(self):
         """
         データの変換を行う
-        :type target_fields: list
         :rtype: list of dict
         """
-        if self.config.has_cache(target_fields=target_fields):
+        if self.config.has_cache():
             self.echo('hit cache')
-            return self.config.get_cache(target_fields=target_fields)
+            return self.config.get_cache()
 
         self.echo('load sheet start')
         start_at = datetime.datetime.now()
@@ -48,7 +49,7 @@ class Converter(object):
 
         self.echo('convert start')
         start_at = datetime.datetime.now()
-        _data = self.config.convert(sheet, target_fields=target_fields)
+        _data = self.config.convert(sheet)
         self.echo('convert end', start_at=start_at)
         return _data
 
